==> zen-cortex-7.0.4.tgz: package/utils/core.js <==
import { getOptionValue } from "./index";

//mapping from entity kind to entity base endpoint location
const entityKindMap = {
  D: "/documents",
  F: "/folders",
  B: "/binders",
  W: "/workspaces",
  Z: "/documents/Z/versions",
  QS: "/quicksearch",
  SS: "/storedsearches",
  AS: "/advancedsearch"
};

/** Get entity base endpoint location depending on its kind.
 * @param {object} entity
 * @param {object} user - connected user (required only for views)
 * @return {string} base URL endpoint for web-service entity
 */
const getEntityEndpoint = (entity, user) => {
  if (entity) {
    return entityKindMap[getKind(entity)] || `/workspaces/${user}/views`;
  }
  return "";
};

/** Get entity identifier used for entity web-services
 * @param {object} entity
 * @return {string} identifier of 'real' targeted entity
 */
export const getId = ({ Id, TargetId }) => TargetId || Id;

/** Get entity kind
 * @param {object} entity
 * @return {string} Kind
 */
export const getKind = ({ Kind, TargetKind }) => TargetKind || Kind;

/** Get entity generic route (ex : /binders/Z001234/sub)
 * @param {object} entity
 * @param {string} suffix - (optional) suffix endpoint
 * @param {string} user - (optional) user identifier
 * @returns {string} computed complete endpoint
 */
export const getEndpoint = (entity, suffix = null, user = null) => {
  const endpoint = `${getEntityEndpoint(entity, user)}/${getId(entity)}`;
  if (suffix) return `${endpoint}/${suffix}`;
  return endpoint;
};

/** Get entity generic short route (ex : /B/Z001234)
 * @param {object} entity
 * @returns {string} computed short endpoint
 */
export const getEndpointShort = entity => `${getKind(entity)}/${getId(entity)}`;

/** STATE slice SELECTORS */

//state selector for config
export const selectConfig = state => state.config;

//state selector for JWT session token
export const getSession = state => state.session;
export const selectToken = state => getSession(state).token;

//state selector for settings
export const getSettings = state => state.settings;

//state selector for user
export const getCurrentUser = state => getSettings(state).User;
export const getCurrentUserId = state => getCurrentUser(state).Id;

//state selector for zen port
export const getZenPort = state =>
  getOptionValue(getSettings(state), "Port", 2500);

//helpers for kind check
export const isDoc = x => getKind(x) === "D";
export const isWorkspace = x => getKind(x) === "W";
export const isShare = x => x.Kind === "S";
export const isVersion = x => getKind(x) === "Z";
export const isSnap = x => x.Type && x.Type.Id === "SNAP";
export const isIndexed = x => (isShare(x) ? x.TargetIndexed : x.Indexed);

==> zen-cortex-7.3.1.tgz: package/utils/core.js <==
import { getOptionValue } from "./index";

export const Kind = {
  Workspace: "W",
  Binder: "B",
  Folder: "F",
  Document: "D",
  View: "V",
  QuickSearch: "QS",
  StoredSearch: "SS",
  AdvancedSearch: "AS",
  Version: "Z",
  Template: "T",
  State: "ST",
  Type: "TP",
  Stamp: "SP"
};

//mapping from entity kind to entity base endpoint location
const entityKindMap = {
  [Kind.Document]: "/documents",
  [Kind.Folder]: "/folders",
  [Kind.Binder]: "/binders",
  [Kind.Workspace]: "/workspaces",
  [Kind.Version]: "/documents/Z/versions",
  [Kind.QuickSearch]: "/quicksearch",
  [Kind.StoredSearch]: "/storedsearches",
  [Kind.AdvancedSearch]: "/advancedsearch"
};

/** Get entity base endpoint location depending on its kind.
 * @param {object} entity
 * @param {object} user - connected user (required only for views)
 * @return {string} base URL endpoint for web-service entity
 */
const getEntityEndpoint = (entity, user) => {
  if (entity) {
    return entityKindMap[getKind(entity)] || `/workspaces/${user}/views`;
  }
  return "";
};

/** Get entity identifier used for entity web-services
 * @param {object} entity
 * @return {string} identifier of 'real' targeted entity
 */
export const getId = ({ Id, TargetId }) => TargetId || Id;

/** Get entity kind
 * @param {object} entity
 * @return {string} Kind
 */
export const getKind = ({ Kind, TargetKind }) => TargetKind || Kind;

/** Get entity generic route (ex : /binders/Z001234/sub)
 * @param {object} entity
 * @param {string} suffix - (optional) suffix endpoint
 * @param {string} user - (optional) user identifier
 * @returns {string} computed complete endpoint
 */
export const getEndpoint = (entity, suffix = null, user = null) => {
  const endpoint = `${getEntityEndpoint(entity, user)}/${getId(entity)}`;
  if (suffix) return `${endpoint}/${suffix}`;
  return endpoint;
};

/** Get entity generic short route (ex : /B/Z001234)
 * @param {object} entity
 * @returns {string} computed short endpoint
 */
export const getEndpointShort = entity => `${getKind(entity)}/${getId(entity)}`;

/** STATE slice SELECTORS */

//state selector for config
export const selectConfig = state => state.config;

//state selector for JWT session token
export const getSession = state => state.session;
export const selectToken = state => getSession(state).token;

//state selector for settings
export const getSettings = state => state.settings;

//state selector for user
export const getCurrentUser = state => getSettings(state).User;
export const getCurrentUserId = state => getCurrentUser(state).Id;

//state selector for zen port
export const getZenPort = state =>
  getOptionValue(getSettings(state), "Port", 2500);

//helpers for kind check
export const isDoc = x => getKind(x) === "D";
export const isWorkspace = x => getKind(x) === "W";
export const isShare = x => x.Kind === "S";
export const isVersion = x => getKind(x) === "Z";
export const isSnap = x => x.Type && x.Type.Id === "SNAP";
export const isIndexed = x => (isShare(x) ? x.TargetIndexed : x.Indexed);
